@@ -192,17 +192,19 @@ class Order(typing.NamedTuple):
 
 
 class OrderBook:
-    def __init__(self, symbol: str, bids: typing.Sequence[Order], asks: typing.Sequence[Order]):
+    def __init__(self, symbol: str, bids: typing.Sequence[Order], asks: typing.Sequence[Order]) -> None:
         self.symbol: str = symbol
 
         # Sort bids high to low, so best bid is at index 0
         bids_list: typing.List[Order] = list(bids)
-        bids_list.sort(key=lambda order: order.price, reverse=True)
+        bids_list.sort(key=lambda order: order.id, reverse=True)
+        # bids_list.sort(key=lambda order: order.price, reverse=True)
         self.bids: typing.Sequence[Order] = bids_list
 
         # Sort bids low to high, so best bid is at index 0
         asks_list: typing.List[Order] = list(asks)
-        asks_list.sort(key=lambda order: order.price)
+        asks_list.sort(key=lambda order: order.id)
+        # asks_list.sort(key=lambda order: order.price)
         self.asks: typing.Sequence[Order] = asks_list
 
     # The top bid is the highest price someone is willing to pay to BUY
@@ -242,7 +244,7 @@ class OrderBook:
             return top_ask.price - top_bid.price
 
     def __str__(self) -> str:
-        def _order_to_str(order: Order):
+        def _order_to_str(order: Order) -> str:
             quantity = f"{order.quantity:,.8f}"
             price = f"{order.price:,.8f}"
             return f"{order.side} {quantity:>20} at {price:>20}"
