@@ -21,7 +21,6 @@ from solana.publickey import PublicKey
 
 from .accountinfo import AccountInfo
 from .addressableaccount import AddressableAccount
-from .constants import SYSTEM_PROGRAM_ADDRESS
 from .context import Context
 from .layouts import layouts
 from .metadata import Metadata
@@ -34,7 +33,7 @@ from .version import Version
 #
 class NodeBank(AddressableAccount):
     def __init__(self, account_info: AccountInfo, version: Version, meta_data: Metadata,
-                 deposits: Decimal, borrows: Decimal, vault: PublicKey):
+                 deposits: Decimal, borrows: Decimal, vault: PublicKey) -> None:
         super().__init__(account_info)
         self.version: Version = version
 
@@ -89,7 +88,7 @@ class RootBank(AddressableAccount):
     def __init__(self, account_info: AccountInfo, version: Version, meta_data: Metadata,
                  optimal_util: Decimal, optimal_rate: Decimal, max_rate: Decimal,
                  node_banks: typing.Sequence[PublicKey], deposit_index: Decimal,
-                 borrow_index: Decimal, last_updated: datetime):
+                 borrow_index: Decimal, last_updated: datetime) -> None:
         super().__init__(account_info)
         self.version: Version = version
 
@@ -177,16 +176,3 @@ class RootBank(AddressableAccount):
 
     def __repr__(self) -> str:
         return f"{self}"
-
-
-def create_null_root_bank() -> RootBank:
-    return RootBank(AccountInfo(SYSTEM_PROGRAM_ADDRESS, False, Decimal(0), SYSTEM_PROGRAM_ADDRESS, Decimal(0), bytes()),
-                    Version.V1,
-                    Metadata(layouts.DATA_TYPE.RootBank, Version.V1, True),
-                    Decimal("0.5"),
-                    Decimal("0.1"),
-                    Decimal(1.5),
-                    [],
-                    Decimal(5),
-                    Decimal(2),
-                    datetime.now())
