@@ -17,9 +17,12 @@ import logging
 import typing
 
 from decimal import Decimal
+from solana.publickey import PublicKey
 
+from .cache import RootBankCache, Cache
+from .context import Context
 from .instrumentlookup import InstrumentLookup
-from .rootbank import RootBank
+from .rootbank import NodeBank, RootBank
 from .token import Instrument, Token
 
 
@@ -28,14 +31,13 @@ from .token import Instrument, Token
 # `TokenInfo` defines additional information for a `Token`.
 #
 class TokenInfo():
-    def __init__(self, token: Token, root_bank: RootBank, decimals: Decimal) -> None:
+    def __init__(self, token: Token, root_bank_address: PublicKey) -> None:
         self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.token: Token = token
-        self.root_bank: RootBank = root_bank
-        self.decimals: Decimal = decimals
+        self.root_bank_address: PublicKey = root_bank_address
 
     @staticmethod
-    def from_layout_or_none(layout: typing.Any, instrument_lookup: InstrumentLookup, root_banks: typing.Sequence[RootBank]) -> typing.Optional["TokenInfo"]:
+    def from_layout_or_none(layout: typing.Any, instrument_lookup: InstrumentLookup) -> typing.Optional["TokenInfo"]:
         if layout.mint is None:
             return None
 
@@ -43,13 +45,14 @@ class TokenInfo():
         if instrument is None:
             raise Exception(f"Token with mint {layout.mint} could not be found.")
         token: Token = Token.ensure(instrument)
+        root_bank_address: PublicKey = layout.root_bank
+        decimals: Decimal = layout.decimals
 
-        if layout.decimals != token.decimals:
+        if decimals != token.decimals:
             raise Exception(
-                f"Conflict between number of decimals in token static data {token.decimals} and group {layout.decimals} for token {token.symbol}.")
+                f"Conflict between number of decimals in token static data {token.decimals} and group {decimals} for token {token.symbol}.")
 
-        root_bank = RootBank.find_by_address(root_banks, layout.root_bank)
-        return TokenInfo(token, root_bank, layout.decimals)
+        return TokenInfo(token, root_bank_address)
 
     @staticmethod
     def find_by_symbol(values: typing.Sequence[typing.Optional["TokenInfo"]], symbol: str) -> "TokenInfo":
@@ -63,10 +66,19 @@ class TokenInfo():
 
         return found[0]
 
+    def root_bank_cache_from_cache(self, cache: Cache, index: int) -> typing.Optional[RootBankCache]:
+        return cache.root_bank_cache[index]
+
+    def load_root_bank(self, context: Context) -> RootBank:
+        return RootBank.load(context, self.root_bank_address)
+
+    def pick_node_bank(self, context: Context) -> NodeBank:
+        root_bank: RootBank = self.load_root_bank(context)
+        return root_bank.pick_node_bank(context)
+
     def __str__(self) -> str:
-        root_bank = f"{self.root_bank}".replace("\n", "\n    ")
         return f"""« 𝚃𝚘𝚔𝚎𝚗𝙸𝚗𝚏𝚘 {self.token}
-    {root_bank}
+    Root Bank Address: {self.root_bank_address}
 »"""
 
     def __repr__(self) -> str:
